/*****************************************************************
**
** Module:      tpro.h
** Date:        08/08/2007
** Purpose:     Contains structures and definions used to interface
**              with the TPRO-PCI or TSAT-PCI API.  Applications
**              that access the API should include this header.
**
** Copyright(C) 2007 Spectracom Corporation. All Rights Reserved
**
******************************************************************
** Modifications:
**
**              08/08/2007 Multi-user enablement
**
******************************************************************/

#ifndef _defined_TPRO_
#define _defined_TPRO_

#pragma pack(8)

#ifdef __cplusplus
extern "C" {
#endif

#ifndef DLL_EXPORT
#define DLL_EXPORT __declspec(dllexport)
#endif

/***************************************************************************
			 SUPPORT CONSTANTS
***************************************************************************/


/**
***  Heartbeat constants
**/

#define SIG_PULSE 	(0xE5)		// signal type for PCI card
#define SIG_SQUARE	(0xE7)		// signal type for PCI card

#define SIG_NO_JAM	(0)		// output type for PCI card
#define SIG_JAM		(1)		// output type for PCI card

#define HEART_NORMAL	(0)		// signal type for CPCI card
#define HEART_INVERT	(8)		// signal type for CPCI card

#define HEART_DISABLE	(0)		// output type for CPCI card
#define HEART_ENABLE	(4)		// output type for CPCI card

#define CLK_10MHZ	(0)		// clock frequency for CPCI board
#define CLK_3MHZ	(1)		// clock frequency for CPCI board
#define CLK_1MHZ	(2)		// clock frequency for CPCI board
#define CLK_1KHZ	(3)		// clock frequency for CPCI board

    /*
** Length of firmware rev string
*/
#define TPRO_FIRMWARE_LENGTH        ( 4 )

/*
** Length of driver version string "XX.YY"
** (not including termination)
*/
#define TPRO_DRV_VERSION_LENGTH     ( 5 )

/**
***  Match constants
**/

#define MATCH_TIME_START	(0)		// start time
#define MATCH_TIME_STOP		(1)		// stop time

/*
**  board sync options
*/
#define TPRO_DISABLE_SYNC           ( 0x0 )     /* freewheel */
#define TPRO_ENABLE_SYNC            ( 0x1 )     /* sync to input */
#define TPRO_SYNC_STAT_FREE         ( 0x0 )     /* sync is freewheel */

/**
***  Oscillator frequencies - for Compact PCI Card Only
**/

#define OSC_OUT_OFF		(0)
#define OSC_OUT_1KHZ		(1)
#define OSC_OUT_1MHZ		(2)
#define OSC_OUT_5MHZ		(3)
#define OSC_OUT_10MHZ		(4)


/***************************************************************************
			      OBJECTS
***************************************************************************/

/*==========================================================================
			 TPRO BOARD OBJECT
==========================================================================*/

typedef struct TPRO_BoardObj
{ /*----------------------------------------------------------------------*/
  void *hDevice;

  unsigned short options;
  unsigned char devid;
} /*----------------------------------------------------------------------*/
TPRO_BoardObj;


/*==========================================================================
			TPRO ALTITUDE OBJECT
==========================================================================*/

typedef struct TPRO_AltObj
{ /*----------------------------------------------------------------------*/
  float         meters;				/*-- meters --------------*/
} /*----------------------------------------------------------------------*/
TPRO_AltObj;


/*==========================================================================
			  TPRO DATE OBJECT
==========================================================================*/

typedef struct TPRO_DateObj
{ /*----------------------------------------------------------------------*/
  unsigned short year;				/*-- year ----------------*/
  unsigned char  month;				/*-- month ---------------*/
  unsigned char  day;				/*-- day -----------------*/
} /*----------------------------------------------------------------------*/
TPRO_DateObj;


/*==========================================================================
		  TPRO LONGITUDE/LATTITUDE OBJECT
==========================================================================*/

typedef struct TPRO_LongLat
{ /*----------------------------------------------------------------------*/
  unsigned short degrees;			/*-- degrees -------------*/
  float   	 minutes;			/*-- minutes -------------*/
} /*----------------------------------------------------------------------*/
TPRO_LongObj, TPRO_LatObj;


/*==========================================================================
			 TPRO MATCH OBJECT
==========================================================================*/

typedef struct TPRO_MatchObj
{ /*----------------------------------------------------------------------*/
  unsigned char   matchType;			/*-- start/stop time -----*/

  double 	  seconds;			/*-- seconds -------------*/
  unsigned char   minutes;			/*-- minutes -------------*/
  unsigned char   hours;			/*-- hours ---------------*/
  unsigned short  days;				/*-- days ----------------*/
} /*----------------------------------------------------------------------*/
TPRO_MatchObj;


/*==========================================================================
			TPRO SATINFO OBJECT
==========================================================================*/

typedef struct TPRO_SatObj
{ /*----------------------------------------------------------------------*/
  unsigned char satsTracked;			/*-- num sats tracked ----*/
  unsigned char satsView;			/*-- num sats in view ----*/
} /*----------------------------------------------------------------------*/
TPRO_SatObj;


/*==========================================================================
		       TPRO HEARTBEAT OBJECT
==========================================================================*/

typedef struct TPRO_HeartObj
{ /*----------------------------------------------------------------------*/
  unsigned char signalType;		    	/*-- heart signal type ---*/
  unsigned char outputType;			/*-- jamming option ------*/

  unsigned char clockFreq;			/*-- clock freq for CPCI -*/

  double  frequency;				/*-- heartbeat freq ------*/
} /*----------------------------------------------------------------------*/
TPRO_HeartObj;


/*==========================================================================
			  TPRO TIME OBJECT
==========================================================================*/

typedef struct TPRO_TimeObj
{ /*----------------------------------------------------------------------*/
  double	 secsDouble;			/*-- seconds -------------*/
  unsigned char	 seconds;			/*-- seconds -------------*/

  unsigned char  minutes;			/*-- minutes -------------*/
  unsigned char  hours;				/*-- hours ---------------*/
  unsigned short days;				/*-- days ----------------*/

  unsigned short year; 				/*-- year for CPCI board -*/
  unsigned short flags;      /* bit 15 flagsInvalid(1); bit 2 SYNC, bit 1 TCODE; all others 0 */
} /*----------------------------------------------------------------------*/
TPRO_TimeObj;


/*==========================================================================
			  TPRO WAIT OBJECT
==========================================================================*/

typedef struct TPRO_WaitObj
{ /*----------------------------------------------------------------------*/
  unsigned int ticks;				/*-- # ticks to wait -----*/

  double	 seconds;			/*-- seconds -------------*/
  unsigned char  minutes;			/*-- minutes -------------*/
  unsigned char  hours;				/*-- hours ---------------*/
  unsigned short days;				/*-- days ----------------*/

  unsigned short year;				/*-- year for cPCI card --*/
  unsigned char  month;				/*-- month for cPCI card -*/
  unsigned char  day;				/*-- day for cPCI card ---*/
} /*----------------------------------------------------------------------*/
TPRO_WaitObj;

/*==========================================================================
		   TPRO MEM OBJECT FOR PEEK/POKE
==========================================================================*/

typedef struct TPRO_MemObj
{ /*----------------------------------------------------------------------*/
  unsigned short offset;
  unsigned long  value;
} /*----------------------------------------------------------------------*/
TPRO_MemObj;


/***************************************************************************
			    ERROR CODES
***************************************************************************/

#include "tpro_error_codes.h"

/***************************************************************************
		     PUBLIC ROUTINE PROTOTYPES
***************************************************************************/

DLL_EXPORT
unsigned char TPRO_open             (TPRO_BoardObj **hnd, char *deviceName);

DLL_EXPORT
unsigned char TPRO_close	    (TPRO_BoardObj *hnd);

DLL_EXPORT
unsigned char TPRO_flushFIFO	    (TPRO_BoardObj *hnd);

DLL_EXPORT
unsigned char TPRO_getAltitude      (TPRO_BoardObj *hnd, TPRO_AltObj *Altp);

DLL_EXPORT
unsigned char TPRO_getDate          (TPRO_BoardObj *hnd, TPRO_DateObj *Datep);

DLL_EXPORT
unsigned char TPRO_getDriver	    (TPRO_BoardObj *hnd, char *driver);

DLL_EXPORT
unsigned char TPRO_getFirmware	    (TPRO_BoardObj *hnd, char *firmware);

DLL_EXPORT
unsigned char TPRO_getFPGA	    (TPRO_BoardObj *hnd, char *fpga);

DLL_EXPORT
unsigned char TPRO_getLatitude      (TPRO_BoardObj *hnd, TPRO_LatObj *Latp);

DLL_EXPORT
unsigned char TPRO_getLongitude     (TPRO_BoardObj *hnd, TPRO_LongObj *Longp);

DLL_EXPORT
unsigned char TPRO_getSatInfo       (TPRO_BoardObj *hnd, TPRO_SatObj *Satp);

DLL_EXPORT
unsigned char TPRO_getTime	    (TPRO_BoardObj *hnd, TPRO_TimeObj *Timep);

DLL_EXPORT
unsigned char TPRO_resetFirmware    (TPRO_BoardObj *hnd);

DLL_EXPORT
unsigned char TPRO_setHeartbeat     (TPRO_BoardObj *hnd, TPRO_HeartObj *Heartp);

DLL_EXPORT
unsigned char TPRO_setMatchTime     (TPRO_BoardObj *hnd, TPRO_MatchObj *Matchp);

DLL_EXPORT
unsigned char TPRO_setOscillator    (TPRO_BoardObj *hnd, unsigned char *freq);

DLL_EXPORT
unsigned char TPRO_setPropDelayCorr (TPRO_BoardObj *hnd, int *us);

DLL_EXPORT
unsigned char TPRO_setTime          (TPRO_BoardObj *hnd, TPRO_TimeObj *Timep);

DLL_EXPORT
unsigned char TPRO_setYear          (TPRO_BoardObj *hnd, unsigned short *yr);

DLL_EXPORT
unsigned char TPRO_simEvent	    (TPRO_BoardObj *hnd);

DLL_EXPORT
unsigned char TPRO_synchControl     (TPRO_BoardObj *hnd, unsigned char *enbp);

DLL_EXPORT
unsigned char TPRO_synchStatus      (TPRO_BoardObj *hnd, unsigned char *status);

DLL_EXPORT
unsigned char TPRO_waitEvent        (TPRO_BoardObj *hnd, TPRO_WaitObj *waitp);

DLL_EXPORT
unsigned char TPRO_waitHeartbeat    (TPRO_BoardObj *hnd, unsigned int *ticks);

DLL_EXPORT
unsigned char TPRO_waitMatch        (TPRO_BoardObj *hnd, unsigned int *ticks);

DLL_EXPORT
unsigned char TPRO_peek	    	    (TPRO_BoardObj *hnd, TPRO_MemObj *Mem);

DLL_EXPORT
unsigned char TPRO_poke		    (TPRO_BoardObj *hnd, TPRO_MemObj *Mem);

#ifdef __cplusplus
}
#endif

#pragma pack()

#endif	// _defined_TPRO_
